# genquiz

Create *individual* questions for online examination

# Installation
```
pip install genquiz
```

*(tested on Python 3.7)*

# Getting Started
Please follow this link:

https://youtu.be/UEX7Ln70_Q4


## Authors

* **Parinya Sanguansat**


## License

This project is licensed under the GNU General Public License v3 or later (GPLv3+)

## Alternatives
What is similar to `genquiz`? `genquiz` is not only generate quiz, but it is also automate grading.

### Generator
1. [Wolfram Problem Generator](https://www.wolframalpha.com/pro/problem-generator/) - For student who can pay [example](https://www.wolframalpha.com/problem-generator/quiz/?category=Algebra&topic=FactorPolynomial)
2. [Microsoft Onenote](https://www.youtube.com/watch?v=UWYqeoM8CvU) - For Arithmetic problem only
3. [The Math Worksheet](https://themathworksheetsite.com/) - for grade 6

### Auto grading
1. [nbgrader](https://github.com/jupyter/nbgrader) - Jupyter notebook grading
2. [Gradescope](https://www.gradescope.com/)

### Online quiz
1. [ProProfs](https://quiz.proprofs.com/how-do-i-create-math-quizzes-with-symbols-and-mathematical-formulas)